summaryrefslogtreecommitdiff
path: root/pkg/domain/entities
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-12-11 10:38:17 -0500
committerGitHub <noreply@github.com>2020-12-11 10:38:17 -0500
commitb0a287ce46ee8326d25efc1e3b9d690eb1e1bbab (patch)
treea08d6774ca2167f8c809c4488483f978a681c843 /pkg/domain/entities
parent99ac30a88287e2c174e69812293f6b130f7a67d5 (diff)
parentba545c49a216d20be83bdfb0357a4d5f0abe6800 (diff)
downloadpodman-b0a287ce46ee8326d25efc1e3b9d690eb1e1bbab.tar.gz
podman-b0a287ce46ee8326d25efc1e3b9d690eb1e1bbab.tar.bz2
podman-b0a287ce46ee8326d25efc1e3b9d690eb1e1bbab.zip
Merge pull request #8686 from Luap99/logs-stderr
podman logs honor stderr correctly
Diffstat (limited to 'pkg/domain/entities')
-rw-r--r--pkg/domain/entities/containers.go6
1 files changed, 4 insertions, 2 deletions
diff --git a/pkg/domain/entities/containers.go b/pkg/domain/entities/containers.go
index 39d679eaf..01086a2b3 100644
--- a/pkg/domain/entities/containers.go
+++ b/pkg/domain/entities/containers.go
@@ -227,8 +227,10 @@ type ContainerLogsOptions struct {
Tail int64
// Show timestamps in the logs.
Timestamps bool
- // Write the logs to Writer.
- Writer io.Writer
+ // Write the stdout to this Writer.
+ StdoutWriter io.Writer
+ // Write the stderr to this Writer.
+ StderrWriter io.Writer
}
// ExecOptions describes the cli values to exec into